=======
Namedex
=======


.. image:: https://img.shields.io/pypi/v/namedex.svg
        :target: https://pypi.python.org/pypi/namedex

.. image:: https://img.shields.io/travis/JoelMon/namedex.svg
        :target: https://travis-ci.org/JoelMon/namedex

.. image:: https://readthedocs.org/projects/namedex/badge/?version=latest
        :target: https://namedex.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/JoelMon/namedex/shield.svg
     :target: https://pyup.io/repos/github/JoelMon/namedex/
     :alt: Updates



Soundex implemented in Python.


* Free software: GNU General Public License v3
* Documentation: https://namedex.readthedocs.io.


Features
--------

* Convert names into a soundex.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
